@@ -312,7 +312,7 @@ class AdjustColumnSize(QDialog):  # {{{
     def resize_to_fit_button_clicked(self):
         self.view.resizeColumnToContents(self.column)
         w = self.view.horizontalHeader().sectionSize(self.column)
-        w = w if w <= self.maximum_size else self.maximum_size
+        w = min(w, self.maximum_size)
         self.spin_box.setValue(w)
 
     def set_maximum_button_clicked(self):
@@ -964,7 +964,7 @@ class BooksView(TableView):  # {{{
         sizes = state.get('column_sizes', {})
         for col, size in sizes.items():
             if col in cmap:
-                sz = sizes[col]
+                sz = size
                 if sz < 3:
                     sz = h.sectionSizeHint(cmap[col])
                 h.resizeSection(cmap[col], sz)
